==> dcc-insider-plugin_0.1.4.tar.xz: BUILD/translations/dcc-insider-plugin.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>InsiderModule</name>
    <message>
        <location filename="../insidermodule.cpp" line="30"/>
        <source>Technology Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../insidermodule.cpp" line="37"/>
        <source>Currently stable Display Manager (lightdm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../insidermodule.cpp" line="41"/>
        <source>Technology preview Display Manager/Window Manager (ddm/treeland)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../insidermodule.cpp" line="45"/>
        <source>New Display Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../insidermodule.cpp" line="69"/>
        <source>Currently stable Input Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../insidermodule.cpp" line="73"/>
        <source>Technology preview Input Method (deepin-im)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../insidermodule.cpp" line="77"/>
        <source>New Input Method</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> dcc-insider-plugin_0.1.11.tar.xz: BUILD/translations/dcc-insider-plugin.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>InsiderModule</name>
    <message>
        <location filename="../dcc-insider-plugin/insidermodule.cpp" line="30"/>
        <source>Technology Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dcc-insider-plugin/insidermodule.cpp" line="37"/>
        <source>Currently stable Display Manager (lightdm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dcc-insider-plugin/insidermodule.cpp" line="41"/>
        <source>Technology preview Display Manager/Window Manager (ddm/treeland)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dcc-insider-plugin/insidermodule.cpp" line="45"/>
        <source>New Display Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dcc-insider-plugin/insidermodule.cpp" line="72"/>
        <source>Currently stable Input Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dcc-insider-plugin/insidermodule.cpp" line="76"/>
        <source>Technology preview Input Method (deepin-im)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dcc-insider-plugin/insidermodule.cpp" line="80"/>
        <source>New Input Method</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
